;; Generated package description from denote-markdown.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "denote-markdown" "0.2.1.0.20251201.50143" "Extensions that better integrate Denote with Markdown" '((emacs "28.1") (denote "4.0.0")) :commit "a7d7e1c1dd609abec2a8bdd0197782f62885d95b" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :url "https://github.com/protesilaos/denote-markdown")
